@@ -15,8 +15,8 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE);
-$VERSION = '1.15';
-$DATE = '2004/05/11';
+$VERSION = '1.16';
+$DATE = '2004/05/18';
 $FILE = __FILE__;
 
 use File::Spec; # Added mkpath option, 2003/11/10
@@ -31,11 +31,9 @@ require Exporter;
 use vars qw($default_options);
 $default_options =  File::SmartNL->defaults();
 
-use SelfLoader;
-
-1
-
-__DATA__
+# use SelfLoader;
+# 1
+# __DATA__
 
 
 #######
@@ -97,15 +95,18 @@ sub fin
    # the file is opened and the file name is a 
    # file handle.
    #
-   my $fh;
-   if( ref($file) eq 'GLOB' ) {
+   my ($fh,$is_handle);
+   if( (UNIVERSAL::isa($file,'GLOB') or UNIVERSAL::isa(\$file,'GLOB')) 
+		and defined fileno($file) ) {
        $fh = $file;
+       $is_handle = 1;
    }
    else {
        unless(open $fh, "<$file") {
            $event = "# Cannot open <$file\n#\t$!";
            goto EVENT;
        }
+       $is_handle = 0;
    } 
 
    #####
@@ -118,9 +119,11 @@ sub fin
    #####
    # Close the file
    #
-   unless(close($fh)) {
-       $event = "# Cannot close $file\n#\t$!";
-       goto EVENT;
+   unless($is_handle) {
+       unless(close($fh)) {
+           $event = "# Cannot close $file\n#\t$!";
+           goto EVENT;
+       }
    }
    return $data unless( $data );
 
@@ -134,7 +137,7 @@ sub fin
 
 EVENT:
    $event .= "\tFile::SmartNL::fin $VERSION\n";  
-   if($options->warn) {
+   if($options->{warn}) {
        warn( $event );
        return undef;
    }         
@@ -189,7 +192,7 @@ sub fout
 
 EVENT:
    $event .= "\n#\tFile::SmartNL::fout $VERSION\n";  
-   if($options->warn) {
+   if($options->{warn}) {
        warn( "# Cannot close $file\n");
        return undef;
    }         
